# Options
set -o shwordsplit


# Aliases
alias zz='source ~/.zshrc'
alias vz='vim ~/.zshrc && source ~/.zshrc'
alias vp='vim $ZSH/plugins/david.zsh && source ~/.zshrc'
alias vt='vim $ZSH/themes/david.zsh && source ~/.zshrc'
alias vs='vim $ZSH/myzsh.sh && source ~/.zshrc'
alias vu='cd $ZSH > /dev/null; git pull origin master; cd - > /dev/null; echo $timestamp > $ZSH/lastrun; source ~/.zshrc'
alias vi='vim'
alias v='vim'
alias publish="python2 -m SimpleHTTPServer"
alias push="git push origin master"
alias pull="git pull origin master"
#alias vpn="sudo openvpn --writepid /var/run/openvpn --config /home/david/.vpn/david.conf"
alias aec="sshuttle -vvr 90.146.8.233 192.168.6.0/24 90.146.8.0/26 10.9.0.0/26 10.12.0.0/16 10.2.0.0/26 192.168.3.0/24 10.12.4.0/22"
alias home="sshuttle -vvr stargazer.socialnerds.org:2222 10.1.0.0/16"
alias dmz="sshuttle -vvr 90.146.8.9 90.146.8.0/26"
alias c="clear"
alias start_vmware="~/Git/scripts/start_vmware.sh"

alias pacrepo='sudo reflector -l 20 -f 10 --save /etc/pacman.d/mirrorlist'
alias pacman='sudo pacman'
alias journalctl='sudo journalctl'
alias pacu='sudo pacman -Syu --noconfirm'
alias auru='yaourt -Syua --noconfirm'
alias systemctl='sudo systemctl'
alias se='ls /usr/bin | grep'

export EDITOR=vim
export QT_STYLE_OVERRIDE=gtk
export QT_SELECT=qt5

if [[ $LANG = '' ]]; then
	export LANG=en_US.UTF-8
fi


# Functions
vm()
{
    if [ -z $1 ]; then
        echo -e "option[new|start|nofb]: \c"
		read option
	else
		option=$1
	fi

	if [ -z $2 ]; then
	    echo -e "filename: \c"
		read filename
	else
		filename=$2
	fi

    if [ $option = "new" ]; then
        qemu-img create -f qcow2 $2 20G
        sudo qemu-system-x86_64 -vga virtio -display sdl,gl=on \
	                        -cpu host -enable-kvm -machine type=pc,accel=kvm -smp 4 \
		                -m 4096 \
    				-drive file=$filename,if=virtio \
                		-net nic,macaddr=$(genmac.sh) \
                                -net bridge,br=br0 \
				-boot order=n

    elif [ $option = "start" ]; then
        sudo qemu-system-x86_64 -vga virtio -display sdl,gl=on \
		                -cpu host -enable-kvm -machine type=pc,accel=kvm -smp 4 \
			        -m 4096 \
                		-drive file=$filename,if=virtio \
                		-net nic,macaddr=$(genmac.sh) \
                                -net bridge,br=br0
    elif [ $option = "net" ]; then
        sudo qemu-system-x86_64 -vga virtio -display sdl,gl=on \
		                -cpu host -enable-kvm -machine type=pc,accel=kvm -smp 4 \
			        -m 4096 \
                		-drive file=$filename,if=virtio \
                		-net nic,macaddr=$(genmac.sh) \
                                -net bridge,br=br0 \
				-boot order=n
    elif [ $option = "low" ]; then
        sudo qemu-system-x86_64 -vga std \
		                -cpu host -enable-kvm -machine type=pc,accel=kvm -smp 4 \
			        -m 4096 \
                		-drive file=$filename,if=virtio \
                		-net nic,macaddr=$(genmac.sh) \
                                -net bridge,br=br0
    elif [ $option = "nofb" ]; then
        sudo qemu-system-x86_64 -nographic -curses \
		                -cpu host -enable-kvm -machine type=pc,accel=kvm -smp 4 \
			        -m 4096 \
                		-drive file=$filename,if=virtio \
                		-net nic,macaddr=$(genmac.sh) \
                                -net bridge,br=br0
    else
	echo "option unknown"
    fi
}

rdp()
{

    if [ -z $1 ]; then
        echo -e "server: \c"
        read  server
    else
        server=$1
    fi

    echo -e "username [davidadm]: \c"
    read username
    if [ -z $username ]; then
        username="davidadm"
    fi

    echo -e "domain [aec.at]: \c"
    read domain
    if [ -z $domain ]; then
        domain="aec.at"
    fi

    which rdesktop >/dev/null
    if [ $? -eq 0 ]; then
        #rdesktop -u $username -p - -d $domain -g 1366x768 $server -k de
        rdesktop -K -u $username -p - -d $domain -g workarea $server -k de
    else
	which xfreerdp >/dev/null
        if [ $? -eq 0 ]; then
	    #xfreerdp +clipboard /v:$server /u:$username /d:$domain /size:1920x1080
            xfreerdp /v:$server /u:$username /d:$domain /size:1366x768 -wallpaper:on

        else
	    echo "error: no rdp client found"
	    return 1
        fi
    fi

}

update()
{
    #  OS Upgrade function for various systems.

        #checking for system
        systems="ubuntu arch solus raspbian antergos"
        issue="$(cat /etc/issue)"
        for item in $systems; do
            echo $issue | grep -i $item >> /dev/null
            if [ $? -eq 0 ]; then
                system=$item
            fi
        done

	#trying to update parsed system
        case $system in
            ubuntu|debian|raspbian)
		echo "Updating Ubuntu/Debian.."
                sudo apt-get update && sudo apt-get dist-upgrade
                ;;
            arch|antergos)
		echo "Updating Arch Linux.."
                sudo pacman -Syu
                ;;
	    solus)
		echo "Updating Solus OS.."
		sudo eopkg update-repo && sudo eopkg upgrade
		;;
            ?)
                echo "error: unknown system."
		return 1
                ;;
        esac
	if [ $? -ne 0 ]; then
            echo "error: something went wrong."
	    return 1
	fi

}

install()
{

        #checking for system
        systems="ubuntu arch"
        issue="$(cat /etc/issue)"
        packages=$*
        for item in $systems; do
            echo $issue | grep -i $item >> /dev/null
            if [ $? -eq 0 ]; then
                system=$item
            fi
        done

        case $system in
            ubuntu)
                sudo apt-get install -y $packages
                ;;
            arch)
                sudo pacman -Sy --noconfirm $packages
                ;;
            ?)
                echo "unknown system. could not run install."
                ;;
        esac

}

is_dirty()
{
  local SUBMODULE_SYNTAX=''
  if [[ $POST_1_7_2_GIT -gt 0 ]]; then
        SUBMODULE_SYNTAX="--ignore-submodules=dirty"
  fi
  if [[ -n $(git status -s ${SUBMODULE_SYNTAX}  2> /dev/null) ]]; then
    return 1
  else
    return 0
  fi
}

fixtrackpoint()
{
    xinput set-prop "TPPS/2 IBM TrackPoint" "Evdev Wheel Emulation" 1
    xinput set-prop "TPPS/2 IBM TrackPoint" "Evdev Wheel Emulation Button" 2
    xinput set-prop "TPPS/2 IBM TrackPoint" "Evdev Wheel Emulation Timeout" 200
    xinput set-prop "TPPS/2 IBM TrackPoint" "Evdev Wheel Emulation Axes" 6 7 4 5
    xinput set-prop "TPPS/2 IBM TrackPoint" "Device Accel Constant Deceleration" 0.75
}

